@@ -6,7 +6,7 @@
  */
 
 /*
- * Copyright (c) 2006-2009 Logitech.
+ * Copyright (c) 2006-2011 Logitech.
  *
  * This file is part of libwebcam.
  * 
@@ -35,7 +35,6 @@
 #include <unistd.h>
 #include <stdarg.h>
 #include <sys/ioctl.h>
-#include <linux/videodev.h>
 #include <errno.h>
 #include <iconv.h>
 
@@ -343,22 +342,22 @@ static __u32 get_uvc_request_by_name (const xmlChar *name)
 	if(!name) return request;
 
 	if(xmlStrEqual(name, BAD_CAST("SET_CUR"))) {
-		request = UVC_CONTROL_SET_CUR;
+		request = UVC_CTRL_FLAG_SET_CUR;
 	}
 	else if(xmlStrEqual(name, BAD_CAST("GET_CUR"))) {
-		request = UVC_CONTROL_GET_CUR;
+		request = UVC_CTRL_FLAG_GET_CUR;
 	}
 	else if(xmlStrEqual(name, BAD_CAST("GET_MIN"))) {
-		request = UVC_CONTROL_GET_MIN;
+		request = UVC_CTRL_FLAG_GET_MIN;
 	}
 	else if(xmlStrEqual(name, BAD_CAST("GET_MAX"))) {
-		request = UVC_CONTROL_GET_MAX;
+		request = UVC_CTRL_FLAG_GET_MAX;
 	}
 	else if(xmlStrEqual(name, BAD_CAST("GET_RES"))) {
-		request = UVC_CONTROL_GET_RES;
+		request = UVC_CTRL_FLAG_GET_RES;
 	}
 	else if(xmlStrEqual(name, BAD_CAST("GET_DEF"))) {
-		request = UVC_CONTROL_GET_DEF;
+		request = UVC_CTRL_FLAG_GET_DEF;
 	}
 	return request;
 }
@@ -1243,7 +1242,7 @@ static CResult process_control (xmlNode *node_control, ParseContext *ctx)
 	}
 
 	// Disable the UVC driver's caching mechanism for XU controls
-	xu_control->info.flags |= UVC_CONTROL_AUTO_UPDATE;
+	xu_control->info.flags |= UVC_CTRL_FLAG_AUTO_UPDATE;
 
 	// Add the control to the UVC driver's control list
 	/*
@@ -1262,6 +1261,7 @@ static CResult process_control (xmlNode *node_control, ParseContext *ctx)
 		xu_control->info.flags
 	);
 	*/
+#ifdef UVCIOC_CTRL_ADD
 	int v4l2_ret = ioctl(ctx->v4l2_handle, UVCIOC_CTRL_ADD, &xu_control->info);
 	if(v4l2_ret != 0
 #ifdef DYNCTRL_IGNORE_EEXIST_AFTER_PASS1
@@ -1277,6 +1277,7 @@ static CResult process_control (xmlNode *node_control, ParseContext *ctx)
 			v4l2_ret, errno, strerror(errno));
 		ret = C_V4L2_ERROR;
 	}
+#endif
 
 	// Add the extension unit control definition to the internal list for later
 	// reference by mappings.
@@ -1542,6 +1543,8 @@ static CResult process_dynctrl_doc (xmlDoc *xml_doc, ParseContext *ctx)
 static CResult device_supports_dynctrl(ParseContext *ctx)
 {
 	CResult ret = C_SUCCESS;
+
+#ifdef UVCIOC_CTRL_ADD
 	struct uvc_xu_control_info xu_control = {
 		.entity		= /* UVC_GUID_UVC_PROCESSING */ { 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x01 },
 		.selector	= /* PU_BRIGHTNESS_CONTROL */ 0x02,
@@ -1570,6 +1573,7 @@ static CResult device_supports_dynctrl(ParseContext *ctx)
 		/* Success: Assume not supported */
 		ret = C_NOT_IMPLEMENTED;
 	}
+#endif
 
 	return ret;
 }
